@@ -12,8 +12,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from solumclient.common.apiclient import base as apiclient_base
 from solumclient.common import base as solum_base
-from solumclient.openstack.common.apiclient import base as apiclient_base
 
 
 class LanguagePack(apiclient_base.Resource):
@@ -21,6 +21,11 @@ class LanguagePack(apiclient_base.Resource):
         return "<LanguagePack %s>" % self._info
 
 
+class UserLog(apiclient_base.Resource):
+    def __repr__(self):
+        return "<Log %s>" % self._info
+
+
 class LanguagePackManager(solum_base.CrudManager):
     resource_class = LanguagePack
     collection_key = 'language_packs'
@@ -40,3 +45,16 @@ class LanguagePackManager(solum_base.CrudManager):
     def delete(self, **kwargs):
         return super(LanguagePackManager,
                      self).delete(base_url="/v1", **kwargs)
+
+    def find(self, **kwargs):
+        name_or_uuid = kwargs['name_or_id']
+        return super(LanguagePackManager, self).get(base_url="/v1",
+                                                    lp_id=name_or_uuid)
+
+    def logs(self, **kwargs):
+        self.resource_class = UserLog
+        languagepack = self.find(name_or_id=kwargs['lp_id'])
+        kwargs['lp_id'] = languagepack.uuid
+        url = self.build_url(base_url="/v1", **kwargs)
+        url += '/logs/'
+        return self._list(url)
